package core.api.controller;

import core.api.models.auth.SimpleStatusResponse;
import core.api.models.users.NtfyInformation;
import core.entities.User;
import core.repositories.UserRepository;
import core.services.UserService;
import core.services.ntfy.TaskSchedulingService;
import org.quartz.SchedulerException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.Optional;

@CrossOrigin(origins = "*", maxAge = 3600)
@RestController
@RequestMapping("/api")
public class NtfyController {

    @Autowired private UserRepository userRepository;
    @Autowired private UserService userService;
    @Autowired private TaskSchedulingService taskSchedulingService;
    @GetMapping("/ntfy")
    public ResponseEntity<?> getNtfyInformation() {
        String username = SecurityContextHolder.getContext().getAuthentication().getName();

        Optional<User> userOptional = userRepository.findByUsername(username);
        if(userOptional.isPresent()) {
            return ResponseEntity.ok(new NtfyInformation(userOptional.get()));
        } else {
            return ResponseEntity.status(404).body(new SimpleStatusResponse("failed"));
        }
    }

    @PostMapping("/ntfy")
    public ResponseEntity<?> editNtfyInformation(@Valid @RequestBody NtfyInformation ntfyInformation) {
        String username = SecurityContextHolder.getContext().getAuthentication().getName();
        Optional<User> user = userRepository.findByUsername(username);
        if(user.isPresent()) {
            userService.editNtfyInformation(user.get(), ntfyInformation);
            try {
                taskSchedulingService.scheduleStartReminders();
            } catch (SchedulerException e) {
                throw new RuntimeException(e);
            }
            return ResponseEntity.ok(new SimpleStatusResponse("success"));
        } else {
            return ResponseEntity.status(404).body(new SimpleStatusResponse("failed"));
        }
    }
}
