import {Component, EventEmitter, Input, Output} from '@angular/core';
import {
  BasicScheduleEntityInfo,
  ScheduleInfo,
  ScheduleService,
  TaskOverviewInfo,
  TaskService,
  TaskShortInfo
} from "../../../api";
import {MatSnackBar} from "@angular/material/snack-bar";
import {TaskEditorData} from "../../tasks/task-editor/TaskEditorData";
import {TaskEditorComponent} from "../../tasks/task-editor/task-editor.component";
import {MatDialog} from "@angular/material/dialog";

export interface TaskCreationEmitterInfo {
  taskgroupID: number,
  task: TaskOverviewInfo
}
@Component({
  selector: 'app-task-overview',
  templateUrl: './task-overview.component.html',
  styleUrls: ['./task-overview.component.css']
})
export class TaskOverviewComponent {

  @Input() tasks: TaskOverviewInfo[] = []
  @Input() taskgroupID: number | undefined
  @Output('onStartNow') startNowEmitter: EventEmitter<ScheduleInfo> = new EventEmitter<ScheduleInfo>();
  @Output('onFinished') finishedEmitter: EventEmitter<TaskOverviewInfo> = new EventEmitter<TaskOverviewInfo>();
  @Output('onCreated') creationEmitter: EventEmitter<TaskCreationEmitterInfo> = new EventEmitter<TaskCreationEmitterInfo>();

  constructor(private scheduleService: ScheduleService,
              private snackbar: MatSnackBar,
              private taskService: TaskService,
              private dialog: MatDialog) {

  }
  startTaskNow(task: TaskOverviewInfo) {
    this.scheduleService.schedulesTaskIDNowPost(task.taskID).subscribe({
      next: resp => {
        this.startNowEmitter.emit(resp);
      },
      error: err => {
        if(err.status == 403) {
          this.snackbar.open("No permission", "", {duration: 2000});
        } else if(err.status == 404) {
          this.snackbar.open("Task not found", "", {duration: 2000});
        } else if(err.status == 409) {
          this.snackbar.open("Task is already running", "", {duration: 2000});
        } else {
          this.snackbar.open("Unexpected error", "", {duration: 2000});
        }
      }
    })
  }

  finishTask(task: TaskOverviewInfo) {
    this.taskService.tasksTaskIDFinishPost(task.taskID).subscribe({
      next: resp => {
        this.finishedEmitter.emit(task);
        this.tasks = this.tasks.filter(ct => ct.taskID !== task.taskID)
      },
      error: err => {
        if(err.status == 403) {
          this.snackbar.open("No permission", "", {duration: 2000});
        } else if(err.status == 404) {
          this.snackbar.open("Task not found", "", {duration: 2000});
        } else {
          this.snackbar.open("Unexpected error", "", {duration: 2000});
        }
       }
    })
  }

  openTaskCreation() {
    const editorData: TaskEditorData = {
      task: undefined,
      taskgroupID: this.taskgroupID!
    }
    const dialogRef = this.dialog.open(TaskEditorComponent, {data: editorData, width: "600px"})
    dialogRef.afterClosed().subscribe(res => {
      if(res != undefined) {
        const taskOverviewInfo: TaskOverviewInfo = {
          taskID: res.taskID,
          eta: res.eta,
          limit: res.deadline,
          taskName: res.taskName,
          activeTime: 0,
          overdue: res.overdue,
          taskgroupPath: [],
          finishable: res.finishable
        }
        this.creationEmitter.emit({
          task: taskOverviewInfo,
          taskgroupID: this.taskgroupID!
        })

      }
    })
  }
}
