import {Component, Input, OnInit} from '@angular/core';
import {
  AdvancedScheduleInfo,
  BasicScheduleEntityInfo, BasicScheduleInfo,
  ScheduleInfo,
  ScheduleService,
  TaskEntityInfo,
  TaskgroupEntityInfo
} from "../../../api";
import {MatSnackBar} from "@angular/material/snack-bar";
import {AdvancedSchedulerComponent} from "../advanced-scheduler/advanced-scheduler.component";

@Component({
  selector: 'app-schedule-dashboard',
  templateUrl: './schedule-dashboard.component.html',
  styleUrls: ['./schedule-dashboard.component.css']
})
export class ScheduleDashboardComponent implements OnInit{

  @Input('taskgroup')  taskgroup: TaskgroupEntityInfo | undefined
  @Input('task') task: TaskEntityInfo | undefined
  @Input('schedules') schedules: ScheduleInfo[] = []



  constructor(private scheduleService: ScheduleService,
              private snackbar: MatSnackBar) {

  }

  ngOnInit() {

  }

  reschedule() {
    //todo
  }

  deleteSchedule(deletedSchedule: ScheduleInfo) {
    this.scheduleService.schedulesScheduleIDDelete(deletedSchedule.scheduleID).subscribe({
      next: resp => {
        this.schedules = this.schedules.filter(schedule => schedule.scheduleID !== deletedSchedule.scheduleID);
      },
      error: err => {
        if(err.status == 403) {
          this.snackbar.open("No permission", "", {duration: 2000});
        } else if(err.status == 404) {
          this.snackbar.open("Schedule not found", "", {duration: 2000});
        } else {
          this.snackbar.open("Unexpected error", "",{duration: 2000});
        }
      }
    })
  }

  toBasicSchedule(schedule: ScheduleInfo) {
    return schedule as BasicScheduleInfo
  }

  toAdvancedSchedule(schedule: ScheduleInfo) {
    return schedule as AdvancedScheduleInfo
  }

  calcDurationOfAdvancedSchedule(schedule: ScheduleInfo) {
    const advancedSchedule = schedule as AdvancedScheduleInfo
    const diffMs = new Date(advancedSchedule.scheduleStopTime).getTime() - new Date(advancedSchedule.scheduleStartTime).getTime();
    return Math.floor((diffMs / 1000) / 60);
  }
}
